@@ -1,6 +1,6 @@
 package Dancer2::Plugin::DBIC;
 
-our $VERSION = '0.0012'; # VERSION
+our $VERSION = '0.0013'; # VERSION
 
 use strict;
 use warnings;
@@ -50,7 +50,7 @@ Dancer2::Plugin::DBIC - DBIx::Class interface for Dancer2 applications
 
 =head1 VERSION
 
-version 0.0012
+version 0.0013
 
 =head1 SYNOPSIS
 
@@ -253,7 +253,7 @@ Yanick Champoux <L<https://github.com/yanick>>
 
 =head1 AUTHOR
 
-Naveed Massjouni <naveedm9@gmail.com>
+Naveed Massjouni <naveed@vt.edu>
 
 =head1 COPYRIGHT AND LICENSE
 
